(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[9996],{99092:function(n,t,e){(window.__NEXT_P=window.__NEXT_P||[]).push(["/[type]/[entity]",function(){return e(21228)}])},21228:function(n,t,e){"use strict";e.r(t);var u=e(85893),r=e(11163);e(67294);var i=e(4386),_=e(19953),a=function(){var n=(0,r.useRouter)(),t=n.query,e=t.type,a=t.entity,c=n.query.variant,f=new i.ZP;return(0,u.jsx)(_.Z,{api:f,type:e,entity:a,queryVariant:c})};t.default=a}},function(n){n.O(0,[9774,2888,179],function(){return n(n.s=99092)}),_N_E=n.O()}]);