(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[9635],{62257:function(n,e,r){(window.__NEXT_P=window.__NEXT_P||[]).push(["/admin/users",function(){return r(4945)}])},4945:function(n,e,r){"use strict";r.r(e);var t=r(85893);r(67294);var s=r(57225),i=function(){return(0,t.jsx)(t.Fragment,{children:(0,t.jsx)(s.Z,{})})};e.default=i},57225:function(n,e,r){"use strict";r.d(e,{Z:function(){return Z}});var t=r(47568),s=r(10092),i=r(85893),u=r(4592),c=r(21987),o=r(13614),a=r(37858),l=r(75921),d=r(98102),f=r(58439),h=r(69397),x=r(11163),_=r(67294),j=r(46291);function Z(n){var e=n.roleNameProp,r=void 0===e?"":e,Z=(0,x.useRouter)(),m=(0,_.useState)([]),v=m[0],p=m[1],g=(0,j.rt)(),w=function(){var n=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"";n&&Z.push("/admin/user/"+n)};return(0,_.useEffect)((0,t.Z)(function(){var n;return(0,s.__generator)(this,function(e){switch(e.label){case 0:if(n=[],!r)return[3,2];return[4,g.getRoleUsers(r)];case 1:return n=e.sent(),[3,4];case 2:return[4,g.getUsers()];case 3:n=e.sent(),e.label=4;case 4:return n&&p(n),[2]}})}),[]),(0,i.jsxs)(i.Fragment,{children:[(0,i.jsx)("strong",{style:{float:"left",paddingBottom:"1em"},children:"Users"}),(0,i.jsx)(u.Z,{component:c.Z,children:(0,i.jsxs)(o.Z,{sx:{minWidth:300},"aria-label":"Admin User Table",children:[(0,i.jsx)(a.Z,{children:(0,i.jsx)(l.Z,{children:(0,i.jsx)(d.Z,{children:"Name"})})}),(0,i.jsx)(f.Z,{children:null==v?void 0:v.map(function(n,e){return(0,i.jsx)(l.Z,{hover:!0,children:(0,i.jsx)(d.Z,{children:(0,i.jsx)(h.Z,{onClick:function(){return w(n)},children:n})})},e)})})]})})]})}}},function(n){n.O(0,[9774,2888,179],function(){return n(n.s=62257)}),_N_E=n.O()}]);