self.__BUILD_MANIFEST={__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":["static/chunks/pages/index-c2ee5b1681e97e4b.js"],"/404":["static/chunks/pages/404-baaca4b2f4acc755.js"],"/_error":["static/chunks/pages/_error-3f70f2d61eb8c6dd.js"],"/connections":["static/chunks/pages/connections-1d67ba61869dece6.js"],"/search":["static/chunks/pages/search-175858e61ba25631.js"],"/[type]":["static/chunks/pages/[type]-3c144c056366a40b.js"],"/[type]/[entity]":["static/chunks/pages/[type]/[entity]-7dd8f8c6a6a73667.js"],sortedPages:["/","/404","/_app","/_error","/connections","/search","/[type]","/[type]/[entity]"]},self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB()