"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[4576],{12017:function(e){function n(e){var n;(n=e).languages.ignore={comment:/^#.*/m,entry:{pattern:/\S(?:.*(?:(?:\\ )|\S))?/,alias:"string",inside:{operator:/^!|\*\*?|\?/,regex:{pattern:/(^|[^\\])\[[^\[\]]*\]/,lookbehind:!0},punctuation:/\//}}},n.languages.gitignore=n.languages.ignore,n.languages.hgignore=n.languages.ignore,n.languages.npmignore=n.languages.ignore}e.exports=n,n.displayName="ignore",n.aliases=["gitignore","hgignore","npmignore"]}}]);