(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[5405],{75557:function(n,r,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/",function(){return t(53678)}])},53678:function(n,r,t){"use strict";t.r(r);var u=t(85893),e=t(9008),i=t.n(e);t(67294);var s=t(5813),c=function(){return(0,u.jsxs)("div",{children:[(0,u.jsx)(i(),{children:(0,u.jsx)("title",{children:"Featureform Dashboard"})}),(0,u.jsx)(s.Z,{})]})};r.default=c},9008:function(n,r,t){n.exports=t(5443)}},function(n){n.O(0,[9774,2888,179],function(){return n(n.s=75557)}),_N_E=n.O()}]);