"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[6749],{76942:function(e){function a(e){e.languages.hpkp={directive:{pattern:/\b(?:includeSubDomains|max-age|pin-sha256|preload|report-to|report-uri|strict)(?=[\s;=]|$)/i,alias:"property"},operator:/=/,punctuation:/;/}}e.exports=a,a.displayName="hpkp",a.aliases=[]}}]);