self.__BUILD_MANIFEST={__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":["static/chunks/pages/index-142e8557e4889163.js"],"/404":["static/chunks/pages/404-8d282ae638ce5722.js"],"/_error":["static/chunks/pages/_error-e18771d792fd8fe7.js"],"/admin/group/[groupName]":["static/chunks/pages/admin/group/[groupName]-4ba8b6abfb4b13ca.js"],"/admin/groups":["static/chunks/pages/admin/groups-7ef899e78a46642d.js"],"/admin/role/[roleName]":["static/chunks/pages/admin/role/[roleName]-a4f4cefefad41418.js"],"/admin/roles":["static/chunks/pages/admin/roles-a560426c6514c003.js"],"/admin/user/[userName]":["static/chunks/pages/admin/user/[userName]-5a66d4c05c9e7453.js"],"/admin/users":["static/chunks/pages/admin/users-313d4735cfc2c71a.js"],"/connections":["static/chunks/pages/connections-f98076127418a04b.js"],"/query":["static/chunks/pages/query-f3c47b8d51f1458e.js"],"/search":["static/chunks/pages/search-e03b34f74065bab5.js"],"/tasks":["static/chunks/pages/tasks-70243ca2c0452223.js"],"/[type]":["static/chunks/pages/[type]-7bfcb609b1affd61.js"],"/[type]/[entity]":["static/chunks/pages/[type]/[entity]-44302760e55a8032.js"],sortedPages:["/","/404","/_app","/_error","/admin/group/[groupName]","/admin/groups","/admin/role/[roleName]","/admin/roles","/admin/user/[userName]","/admin/users","/connections","/query","/search","/tasks","/[type]","/[type]/[entity]"]},self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();