"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[7176,3047],{20791:function(e,n,a){var t=a(93205);function s(e){var n;e.register(t),(n=e).languages.ejs={delimiter:{pattern:/^<%[-_=]?|[-_]?%>$/,alias:"punctuation"},comment:/^#[\s\S]*/,"language-javascript":{pattern:/[\s\S]+/,inside:n.languages.javascript}},n.hooks.add("before-tokenize",function(e){n.languages["markup-templating"].buildPlaceholders(e,"ejs",/<%(?!%)[\s\S]+?%>/g)}),n.hooks.add("after-tokenize",function(e){n.languages["markup-templating"].tokenizePlaceholders(e,"ejs")}),n.languages.eta=n.languages.ejs}e.exports=s,s.displayName="ejs",s.aliases=["eta"]},93205:function(e){function n(e){!function(e){function n(e,n){return"___"+e.toUpperCase()+n+"___"}Object.defineProperties(e.languages["markup-templating"]={},{buildPlaceholders:{value:function(a,t,s,o){if(a.language===t){var r=a.tokenStack=[];a.code=a.code.replace(s,function(e){if("function"==typeof o&&!o(e))return e;for(var s,i=r.length;-1!==a.code.indexOf(s=n(t,i));)++i;return r[i]=e,s}),a.grammar=e.languages.markup}}},tokenizePlaceholders:{value:function(a,t){if(a.language===t&&a.tokenStack){a.grammar=e.languages[t];var s=0,o=Object.keys(a.tokenStack);!function r(i){for(var u=0;u<i.length&&!(s>=o.length);u++){var l=i[u];if("string"==typeof l||l.content&&"string"==typeof l.content){var g=o[s],c=a.tokenStack[g],p="string"==typeof l?l:l.content,f=n(t,g),k=p.indexOf(f);if(k>-1){++s;var d=p.substring(0,k),m=new e.Token(t,e.tokenize(c,a.grammar),"language-"+t,c),h=p.substring(k+f.length),v=[];d&&v.push.apply(v,r([d])),v.push(m),h&&v.push.apply(v,r([h])),"string"==typeof l?i.splice.apply(i,[u,1].concat(v)):l.content=v}}else l.content&&r(l.content)}return i}(a.tokens)}}}})}(e)}e.exports=n,n.displayName="markupTemplating",n.aliases=[]}}]);